#
# spec file for package python-zodbpickle
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-zodbpickle
Version:        3.3
Release:        1.1
Summary:        Fork of Python 3 pickle module
License:        Python-2.0 AND ZPL-2.1
Group:          Development/Libraries/Python
URL:            https://pypi.python.org/pypi/zodbpickle
Source:         https://files.pythonhosted.org/packages/source/z/zodbpickle/zodbpickle-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testsuite}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
This package presents a uniform pickling interface for ZODB:
 * Under Python2, this package forks both Python 2.7’s pickle and
   cPickle modules, adding support for the protocol 3 opcodes.
   It also provides a new subclass of bytes, zodbpickle.binary,
   which Python2 applications can use to pickle binary values such
   that they will be unpickled as bytes under Py3k.
 * Under Py3k, this package forks the pickle module (and the
   supporting C extension) from both Python 3.2 and Python 3.3.
   The fork add support for the noload operations used by ZODB.

%prep
%setup -q -n zodbpickle-%{version}
rm -rv src/zodbpickle.egg-info

%build
%pyproject_wheel

%install
%pyproject_install
%{python_expand find %{buildroot}%{$python_sitearch} -name *.c -delete
  %fdupes %{buildroot}%{$python_sitearch}
}

%check
pushd src
mv zodbpickle{,_hide}
%pyunittest_arch -v zodbpickle_hide.tests.test_pickle.test_suite

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst README.rst
%{python_sitearch}/zodbpickle
%{python_sitearch}/zodbpickle-%{version}.dist-info

%changelog
* Thu May  2 2024 Dirk Müller <dmueller@suse.com>
- update to 3.3:
  * Build Windows wheels on GHA.
  * Add preliminary support for Python 3.13 as of 3.13a5.
  * Add preliminary support for Python 3.13 as of 3.13a3.
- use PEP517 build
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1:
  * Add support for Python 3.12.
  * Fix ``NameError`` in ``.fastpickle`` and ``.slowpickle``.
  * Build Linux binary wheels for Python 3.11.
  * Add preliminary support for Python 3.12a5.
  * Drop support for Python 2.7, 3.5, 3.6.
  * Drop support for deprecated ``python setup.py test``.
* Mon Dec  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.6
  * Add support for building arm64 wheels on macOS.
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.5
  * Add support for the final Python 3.11 release.
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.4.0
  * Add support for Python 3.11 (as of 3.11.0b3).
  * Disable unsafe math optimizations in C code. See pull request 73.
* Fri Sep 16 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 2.3.0
  * Add support for Python 3.11 (as of 3.11.0a7).
* Wed Jan 26 2022 pgajdos@suse.com
- version update to 2.2.0
  * - Add support for Python 3.10.
* Fri Sep 24 2021 pgajdos@suse.com
- version update to 2.1.0
  * Add support for Python 3.9.
- use %%pyunittest_arch rpm macro
* Fri Jan 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Use python_module macro for BuildRequires on the testsuite module
* Mon Mar  9 2020 pgajdos@suse.com
- version update to 2.0.0
  - CPython 2: Make ``zodbpickle.binary`` objects smaller and untracked
    by the garbage collector. Now they behave more like the native bytes
    object. Just like it, and just like on Python 3, they cannot have
    arbitrary attributes or be weakly referenced. See `issue 53
    <https://github.com/zopefoundation/zodbpickle/issues/53>`_.
  - Add support for Python 3.8.
  - Drop support for Python 3.4.
* Mon Jun 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.4:
  * Fix pickle corruption under certain conditions. See pull request 47.
* Tue Apr  9 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.0.3
  * Add support for Python 3.7.
  * Fix a bug: zodbpickle.slowpickle assigned _Pickler to Unpickler.
* Thu Jul 26 2018 tchvatal@suse.com
- Update to 1.0.1:
  * Fix a memory leak in pickle protocol 3 under Python 2. See issue 36.
  * Add support for Jython 2.7.
  * Add support for Python 3.5 and 3.6.
  * Drop support for Python 2.6 and 3.2 and 3.3
* Tue Jun 27 2017 aloisio@gmx.com
- Initial package (v. 0.6.0)
